/*!
 * jQuery Remove Uppercase Accents for Drupal 7
 * https://www.drupal.org/project/rua
 *
 * Automatically removes accented characters (currently Greek) from elements
 * having their text content uppercase transformed through CSS.
 *
 * It WILL NOT target fieldset and elements capitalized inside fieldsets!
 */

(function($) {

  $.extend($.expr[":"], {
    uppercase: function(elem) {
      var attr = $(elem).css("text-transform");
      return typeof attr !== "undefined" && attr === "uppercase";
    },
    smallcaps: function(elem) {
      var attr = $(elem).css("font-variant");
      return typeof attr !== "undefined" && attr === "small-caps";
    }
  });

  $.extend({
    removeAcc: function(elem) {
      if (elem.tagName.toLowerCase() === "input") {
        var text = elem.value;
        text = removeAcc(text);
        elem.value = text;
      }
      else {
        var childNodes = elem.childNodes;
        for (var child in childNodes){
          var nodeType = childNodes[child].nodeType;
          // Only replace text nodes
          // @see https://www.w3schools.com/jsref/prop_node_nodetype.asp
          if (nodeType === 3) {
            var nodeValue = childNodes[child].nodeValue;
            nodeValue = removeAcc(nodeValue);
            childNodes[child].nodeValue = nodeValue;
          }
        }
      }
    }
  });

  $.fn.extend({
    removeAcc: function() {
      return this.each(function() {
        $.removeAcc(this);
      });
    }
  });

  // Shorthand for `$(document).ready()`
  $(function() {

    $(":uppercase").removeAcc();
    $(document).ajaxComplete(function() {
      $(":uppercase").removeAcc();
    });

    $(":smallcaps").removeAcc();
    $(document).ajaxComplete(function() {
      $(":smallcaps").removeAcc();
    });

  });

  function removeAcc(text) {
    return text.replace(/Ά/g, "Α")
      .replace(/ά/g, "α")
      .replace(/Έ/g, "Ε")
      .replace(/έ/g, "ε")
      .replace(/Ή/g, "Η")
      .replace(/ή/g, "η")
      .replace(/Ί/g, "Ι")
      .replace(/ί/g, "ι")
      .replace(/ΐ/g, "ϊ")
      .replace(/Ό/g, "Ο")
      .replace(/ό/g, "ο")
      .replace(/Ύ/g, "Υ")
      .replace(/ύ/g, "υ")
      .replace(/ΰ/g, "ϋ")
      .replace(/Ώ/g, "Ω")
      .replace(/ώ/g, "ω")
      .replace(/ς/g, "Σ");
  }

})(jQuery);
